@@ -5,7 +5,7 @@ use warnings;
 use 5.008004;
 
 # ABSTRACT: Alien::Build local config
-our $VERSION = '2.52'; # VERSION
+our $VERSION = '2.77'; # VERSION
 
 
 sub logx ($)
@@ -15,6 +15,24 @@ sub logx ($)
 }
 
 
+sub preload_plugin
+{
+  my(@args) = @_;
+  push @Alien::Build::rc::PRELOAD, sub {
+    shift->apply_plugin(@args);
+  };
+}
+
+
+sub postload_plugin
+{
+  my(@args) = @_;
+  push @Alien::Build::rc::POSTLOAD, sub {
+    shift->apply_plugin(@args);
+  };
+}
+
+
 sub preload ($)
 {
   push @Alien::Build::rc::PRELOAD, $_[0];
@@ -40,7 +58,7 @@ Alien::Build::rc - Alien::Build local config
 
 =head1 VERSION
 
-version 2.52
+version 2.77
 
 =head1 SYNOPSIS
 
@@ -65,14 +83,30 @@ or fetch from a local mirror.
 
 Send a message to the L<Alien::Build> log.
 
+=head2 preload_plugin
+
+ preload_plugin $plugin, @args;
+
+Preload the given plugin, with arguments.
+
+=head2 postload_plugin
+
+ postload_plugin $plugin, @args;
+
+Postload the given plugin, with arguments.
+
 =head2 preload
 
+[deprecated]
+
  preload $plugin;
 
 Preload the given plugin.
 
 =head2 postload
 
+[deprecated]
+
  postload $plugin;
 
 Postload the given plugin.
@@ -153,6 +187,8 @@ Håkon Hægland (hakonhagland, HAKONH)
 
 nick nauwelaerts (INPHOBIA)
 
+Florian Weimer
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011-2022 by Graham Ollis.
